// Estimates the permanent income from the EPF's family demographics data
run "$pathdo2\linear_reg_impute3.do" 
run "$path_bs_do\layoff_jobfind" 
run "$path_bs_do\layoff_jobfind0" 
run "$path_bs_do\income_shock" 
run "$path_bs_do\income_shock0"

use "$path4b\expenditures_${data_save_emp}.dta", clear
local cond_vars "zona2 sexo actividad tedu tr_edad quintile_h"  //`cond_vars'  tr_edad2 educ

// Individual income variables and occupational status
g folio = hogar
g year = 2006
g a1 = parentesco 
g a2 = numero_persona
g actividad = rama_actividad
g sector_ind = actividad
recode sector_ind 0/1=1 2/4=2 5/10=3 // 1/2=1 3/5=2 6/10=3
sum ingreso_trabajador_dependiente ingreso_total ingreso_trabajo_dependiente ingreso_propiedad ingreso_propiedad transferencias arriendo_imputado
sum categoria_ocupacional rama_actividad grupo_ocupacional parentesco
sum ingreso_trabajo_dependiente ingreso_trabajo_independiente grupo_ocupacional if  ingreso_trabajo_dependiente>0

g ytot_ind = ingreso_total
g ocup = 0
replace ocup = 1 if ingreso_trabajo_dependiente>0 & ingreso_trabajo_dependiente<.
replace ocup = 1 if ingreso_trabajo_independiente>0 & ingreso_trabajo_independiente<.
g desem =  1-ocup // 0 if ocup==1 
replace desem = 1 if categoria_ocupacional==6 
replace desem = 1 if grupo_ocupacional==.
replace desem = 1 if rama_actividad==.
replace ocup =. if desem==.
g yai = arriendo_imputado
g yaotp = 0
g yact = 0

capture drop educ_mode
g educ = educacion
recode educ (1/10 = 1) (11/13 = 2) (14/15 = 3)
replace educ = . if educ==98
replace educacion = . if educ==.
bysort zona2 vivprop num_adul num_men tr_edad quintile_h: egen educ_mode = mode(educ), minmode
replace educ = educ_mode if educ==.

// Permanent Income
bysort `cond_vars': egen ytot_ind_pot = median(ytot_ind) if ocup==1 | desem==1
bysort `cond_vars': egen ytot_ind_pot_2 = median(ytot_ind) if ocup==1 | desem==1
replace ytot_ind_pot = ytot_ind_pot_2 if actividad==0 | actividad==. | ytot_ind_pot==.
g ytot_ind2 = ytot_ind
replace ytot_ind2 = (1/2)*ytot_ind_pot if ytot_ind2==. 
replace ytot_ind2 = (1/2)*ytot_ind_pot if ytot_ind2<=(1/2)*ytot_ind_pot & ytot_ind_pot<.
bysort folio: egen ytoth_temp0 = total(ytot_ind2)

egen ytoth_pi = rowtotal(ytoth_temp0 yai)
replace ytoth_pi = max(0,ytoth_pi- yai, ytoth) if yai<.
replace ytoth_pi = max(0,ytoth_pi, ytoth) if ytoth_pi==.
sum ytoth_pi if ytoth_pi>0
replace ytoth_pi = r(min) if ytoth_pi==. | ytoth_pi<=0
replace ytoth_pi =ln(1000+ytoth_pi)

capture drop ytoth_temp0 ytot_ind_pot ytot_ind_pot_2 ytot_ind2 


if ${esi_bt_op}==1 { // Use ESI bootstrap option
layoff_jobfind 12
}
if ${esi_bt_op}==0 {
layoff_jobfind0 12
}
//
rename unemployed pr_unemployed
g factor_un = ceil(factor*(1/pr_unemployed) )
replace factor_un = 1 if factor_un<1
replace factor_un = factor if factor_un==.
g factor_e = ceil(factor*(1/(1-pr_unemployed)) )
replace factor_e = 1 if factor_e<1
replace factor_e = factor if factor_e==.

xtile dec_renta0 = ytot_ind if desem==0 & ytot_ind>0 [fw=factor_e], nq(10)
xtile dec_renta1 = ytot_ind if desem==1 & ytot_ind>0 [fw=factor_un], nq(10)
g dec_renta=dec_renta0 if desem==0
replace dec_renta=dec_renta1 if desem==1 
replace dec_renta=0 if ytot_ind==0 & desem<.
drop dec_renta0 dec_renta1
g quintile_renta = ceil(dec_renta/2)

replace tr_edad = . if tr_edad==0
replace tr_edad2 = . if tr_edad2==0

g unemployed = desem 
capture drop _merge
if ${esi_bt_op}==1 { // Use ESI bootstrap option
income_shock 12
}
if ${esi_bt_op}==0 {
income_shock0 12
}
drop unemployed
capture drop _merge
run "$path_bs_do\p_income" 


g ytoth_pi_exp = exp(ytoth_pi)
foreach x of varlist ytoth_pi_exp ytot_p_h {
capture drop pr_est* 
reg `x' i.(`var_list')
predict pr_est, xb
replace `x'=pr_est if `x'==.
replace `x'=0 if `x'<0
}
//
g ytoth_cons = min(ytot_p_h, ytoth_pi_exp) // Alternatives - ytoth, ytoth_pi_exp

drop folio ytot_ind educ_mode year actividad yai yaotp yact
save "$path4b\expenditures_${data_save_emp}.dta", replace
